Struct diem_jellyfish_merkle::JellyfishMerkleTree[][src]

pub struct JellyfishMerkleTree<'a, R, V> { /* fields omitted */ }
The Jellyfish Merkle tree data structure. See crate for description.

Implementations

Creates a JellyfishMerkleTree backed by the given TreeReader.

The batch version of put_value_sets.

This is a convenient function that calls put_value_sets with a single keyed_value_set.

Returns the new nodes and values in a batch after applying value_set. For example, if after transaction T_i the committed state of tree in the persistent storage looks like the following structure:

             S_i
            /   \
           .     .
          .       .
         /         \
        o           x
       / \
      A   B
       storage (disk)

where A and B denote the states of two adjacent accounts, and x is a sibling subtree of the path from root to A and B in the tree. Then a value_set produced by the next transaction T_{i+1} modifies other accounts C and D exist in the subtree under x, a new partial tree will be constructed in memory and the structure will be:

                S_i      |      S_{i+1}
               /   \     |     /       \
              .     .    |    .         .
             .       .   |   .           .
            /         \  |  /             \
           /           x | /               x'
          o<-------------+-               / \
         / \             |               C   D
        A   B            |
          storage (disk) |    cache (memory)

With this design, we are able to query the global state in persistent storage and generate the proposed tree delta based on a specific root hash and value_set. For example, if we want to execute another transaction T_{i+1}', we can use the tree S_i in storage and apply the value_set of transaction T_{i+1}. Then if the storage commits the returned batch, the state S_{i+1} is ready to be read from the tree by calling get_with_proof. Anything inside the batch is not reachable from public interfaces before being committed.

Returns the value (if applicable) and the corresponding merkle proof.

Gets the proof that shows a list of keys up to rightmost_key_to_prove exist at version.