Trait diem_jellyfish_merkle::TestValue[][src]

pub trait TestValue: Value + Arbitrary + Debug + Eq + PartialEq + 'static { }
TestValue defines the types of data that can be stored in a Jellyfish Merkle tree and used in tests.

Implementations on Foreign Types

Implementors