Trait diem_jellyfish_merkle::Value [−][src]
pub trait Value: Clone + CryptoHash + Serialize + DeserializeOwned { }Expand description
Value defines the types of data that can be stored in a Jellyfish Merkle tree.
pub trait Value: Clone + CryptoHash + Serialize + DeserializeOwned { }Value defines the types of data that can be stored in a Jellyfish Merkle tree.