Trait diem_jellyfish_merkle::TestValue [−][src]
TestValue defines the types of data that can be stored in a Jellyfish Merkle tree and used in
tests.
TestValue defines the types of data that can be stored in a Jellyfish Merkle tree and used in
tests.